@@ -564,7 +564,6 @@ isize_t msg_recv_commit(msg_t *msg, usize_t n, int eos)
 msg_t *msg_next(msg_t *msg)
 {
   msg_t *next;
-  usize_t n;
 
   if (msg && msg->m_next) {
     next = msg->m_next;
@@ -572,7 +571,7 @@ msg_t *msg_next(msg_t *msg)
     return next;
   }
 
-  if ((n = msg_buf_committed(msg))) {
+  if (msg_buf_committed(msg)) {
     if (msg_buf_move(next = msg_create(msg->m_class, msg->m_oflags), msg)) {
       msg_addr_copy(next, msg);
       return next;
@@ -1916,6 +1915,8 @@ int msg_serialize(msg_t *msg, msg_pub_t *pub)
   if (pub == NULL)
     pub = msg->m_object;
 
+  assert(pub);
+
   /* There must be a first line */
   if (pub->msg_request)
     h = pub->msg_request;
