@@ -44,13 +44,12 @@
 
 /** @page nua_api_overview NUA API Overview
  *
- * This page gives a short overview of the NUA API: different functions,
- * events, tags, and where and how they affect the workings of the NUA
- * engine.
+ * This page shortly overviews the NUA API: different functions, tags, and
+ * where and how they affect the working of NUA engine.
  *
  * The application and the NUA engine can pass various parameters between
  * them using tagged arguments. Tagged arguments can be used like named
- * arguments in higher-lever languages.
+ * arguments in higher-lever language.
  *
  * @par NUA Agent
  *
@@ -67,66 +66,54 @@
  * The agent-wide parameter can be later modified or obtained with
  * nua_set_params() and nua_get_params(), respectively.
  *
- * The #su_root_t mainloop integration uses:
+ * The #su_root_t mainloop integration uses
  * - su_root_create(), su_root_threading(),
- *   su_root_step(), su_root_run(), su_root_break()
+ *   su_root_poll(), su_root_run(), su_root_break()
  *
  * @par NUA Handles
- *
  * - nua_handle(), nua_get_hparams(), nua_set_hparams()
  * - nua_handle_home(), nua_handle_has_invite(), nua_handle_has_subscribe(),
  *   nua_handle_has_register(), nua_handle_has_active_call(),
  *   nua_handle_has_call_on_hold(), nua_handle_has_events(),
  *   nua_handle_has_registrations(), nua_handle_remote(), and
- *   nua_handle_local()
- *
- * Settings:
- * - See nua_set_hparams()
- *
- * There are a few "sticky" headers that are used
- *   on subsequent requests if included with any handle-specific call:
+ *   nua_handle_local().
+ * - Settings:
+ *   See nua_set_hparams(). There are a few "sticky" headers that are used
+ *   on subsequent requests if given on any handle-specific call:
  *   - @Contact, @UserAgent, @Supported, @Allow, @Organization
  *
  * @par Client Generating SIP Requests
- *
  * - nua_register(), nua_unregister(), nua_invite(), nua_cancel(),
  *   nua_ack(), nua_bye(), nua_options(), nua_refer(), nua_publish(),
  *   nua_unpublish(), nua_prack(), nua_info(), nua_update(), nua_message(),
  *   nua_subscribe(), nua_unsubscribe(), nua_notify(), nua_method()
  * - NUTAG_URL()
- *
  *  Settings:
  * - NUTAG_RETRY_COUNT(), NUTAG_PROXY(),
  *   NUTAG_INITIAL_ROUTE() and NUTAG_INITIAL_ROUTE_STR()
- * - NUTAG_ALLOW(), SIPTAG_ALLOW() and SIPTAG_ALLOW_STR()
+ * - NUTAG_ALLOW(), SIPTAG_ALLOW(), and SIPTAG_ALLOW_STR()
  * - NUTAG_SUPPORTED(), SIPTAG_SUPPORTED(), and SIPTAG_SUPPORTED_STR()
  * - NUTAG_USER_AGENT(), SIPTAG_USER_AGENT() and SIPTAG_USER_AGENT_STR()
  * - SIPTAG_ORGANIZATION() and SIPTAG_ORGANIZATION_STR()
- * - NUTAG_AUTO302(), NUTAG_AUTO305()
  *
  * @par Client Authenticating Requests
- *
  * - nua_authenticate(), #nua_r_authenticate
  * - NUTAG_AUTH(), NUTAG_AUTH_CACHE()
  *
  * @par Server Processing Received SIP Requests
- *
  * - nua_respond(), NUTAG_WITH_THIS(), NUTAG_WITH_SAVED(), NUTAG_WITH()
  * - #nua_i_invite, #nua_i_cancel, #nua_i_ack, #nua_i_bye,
  *   #nua_i_options, #nua_i_refer, #nua_i_publish, #nua_i_prack,
  *   #nua_i_info, #nua_i_update, #nua_i_message, #nua_i_subscribe,
  *   #nua_i_notify, #nua_i_method, #nua_i_register
- *
  *  Settings:
  * - NUTAG_APPL_METHOD(), NUTAG_PROXY()
  * - NUTAG_ALLOW(), SIPTAG_ALLOW(), and SIPTAG_ALLOW_STR()
  * - NUTAG_SUPPORTED(), SIPTAG_SUPPORTED(), and SIPTAG_SUPPORTED_STR()
  *
  * @par Registrations and Contact Header Generation
- *
  * - nua_register(), #nua_r_register(), #nua_i_outbound,
  *   nua_unregister(), and #nua_r_unregister
- *
  * Settings:
  * - NUTAG_CALLEE_CAPS()
  * - NUTAG_DETECT_NETWORK_UPDATES()
@@ -139,14 +126,13 @@
  * - NUTAG_M_USERNAME()
  * - NUTAG_OUTBOUND()
  * - NUTAG_PATH_ENABLE()
+ * - NUTAG_RETRY_AFTER_ENABLE()
  * - NUTAG_SERVICE_ROUTE_ENABLE()
- *
  * Specifications:
  * - @RFC3261 section 10, @RFC3327, @RFC3608, @RFC3680, @RFC3840,
  *   draft-ietf-sip-outbound, draft-ietf-sip-gruu-14
  *
  * @par INVITE Sessions and Call Model
- *
  * - nua_invite(), #nua_r_invite, #nua_i_invite
  * - nua_handle_has_active_call(), nua_handle_has_call_on_hold(),
  *   nua_handle_has_invite()
@@ -157,90 +143,70 @@
  *   NUTAG_OFFER_SENT(), NUTAG_OFFER_RECV(), NUTAG_ANSWER_RECV(), and
  *   NUTAG_ANSWER_SENT(), SOATAG_REMOTE_SDP(), SOATAG_REMOTE_SDP_STR(),
  *   SOATAG_LOCAL_SDP(), SOATAG_LOCAL_SDP_STR()
- *
  *  Settings:
  * - NUTAG_AUTOACK(), NUTAG_AUTOALERT(), NUTAG_AUTOANSWER(),
  *   NUTAG_ENABLEINVITE(), NUTAG_INVITE_TIMER(), NUTAG_MEDIA_ENABLE(),
  *   SOATAG_USER_SDP(), SOATAG_USER_SDP_STR(), SOATAG_CAPS_SDP(),
  *   SOATAG_CAPS_SDP_STR()
- *
  * Specifications:
  * - @RFC3261, @RFC3264
  *
  * @par In-Session Information requests
- *
  * - nua_info() #nua_r_info, #nua_i_info
- *
  * Settings:
- * - @ref NUTAG_ALLOW("INFO"), @ref NUTAG_APPL_METHOD("INFO")
+ * - NUTAG_ALLOW("INFO"), NUTAG_APPL_METHOD("INFO")
  *
  * @par SDP Processing
- *
  * - #nua_i_state, SOATAG_ACTIVE_AUDIO(), SOATAG_ACTIVE_VIDEO(),
  *   SOATAG_ACTIVE_IMAGE(), SOATAG_ACTIVE_CHAT(),
  *   SOATAG_REMOTE_SDP(), SOATAG_REMOTE_SDP_STR(),
  *   SOATAG_LOCAL_SDP(), SOATAG_LOCAL_SDP_STR()
- *
  * Settings:
  * - NUTAG_MEDIA_ENABLE(), NUTAG_SOA_NAME(), NUTAG_EARLY_ANSWER(),
  *   SOATAG_USER_SDP(), SOATAG_USER_SDP_STR(), SOATAG_CAPS_SDP(),
  *   SOATAG_CAPS_SDP_STR()
- *
  * Specifications:
  * - @RFC3264
  *
  * @par Call Model Extensions ("100rel" and "precondition")
- *
- * Early media:
+ * Early
  * - nua_prack(), #nua_r_prack, #nua_i_prack
  * - nua_update() #nua_r_update, #nua_i_update
- *
  * Settings:
  * - NUTAG_EARLY_MEDIA(), NUTAG_ONLY183_100REL()
- * - "100rel" or "precondition" in NUTAG_SUPPORTED() or SIPTAG_SUPPORTED()
- *
+ * - "100rel" or "precondition" in NUTAG_SUPPORTED()/SIPTAG_SUPPORTED()
  * Specifications:
  * - @RFC3262, @RFC3311, @RFC3312
  *
  * @par SIP Session Timers ("timer")
- *
  * Periodic refresh of SIP Session initiated with INVITE with re-INVITE or
  * UPDATE requests.
- *
  * Settings:
  * - NUTAG_MIN_SE(), NUTAG_SESSION_REFRESHER(),
  *   NUTAG_SESSION_TIMER(), NUTAG_UPDATE_REFRESH(),
  *   NUTAG_REFRESH_WITHOUT_SDP(),
- * - "timer" in NUTAG_SUPPORTED() or SIPTAG_SUPPORTED()
- *
+ * - "timer" in NUTAG_SUPPORTED()/SIPTAG_SUPPORTED()
  * Specifications:
  * - @RFC4028
  *
  * @par Caller Preferences and Callee Caps
- *
- * - Caller preferences in an @AcceptContact header in a INVITE requests
- * - Callee caps contained in a @Contact header in a REGISTER request
- *
+ * - Caller preferences in @AcceptContact header in a INVITE requests
+ * - Callee caps contained in @Contact header in a REGISTER request
  * Settings:
  * - NUTAG_CALLEE_CAPS(), NUTAG_MEDIA_FEATURES(),
  *   NUTAG_M_FEATURES()
- *
  * Specifications:
  * - @RFC3840, @RFC3841
  *
  * @par Instant Messaging
- *
  * - nua_message(), #nua_r_message, #nua_i_message
- *
  * Settings:
- * - @ref NUTAG_APPL_METHOD("MESSAGE"),
+ * - NUTAG_APPL_METHOD("MESSAGE"),
  *   NUTAG_ENABLEMESSAGE(), NUTAG_ENABLEMESSENGER()
- *
  * Specifications:
  * - @RFC3428
  *
  * @par Call Transfer
- *
  * - nua_refer(), #nua_r_refer, #nua_i_notify, SIPTAG_EVENT(),
  *   @ReferTo, SIPTAG_REFER_TO(), @ReferredBy, SIPTAG_REFERRED_BY(),
  *   nua_handle_make_replaces(), @Replaces, SIPTAG_REPLACES(),
@@ -248,83 +214,63 @@
  * - #nua_i_refer, nua_notify(), #nua_r_notify,
  *   nua_handle_by_replaces()
  * - nua_invite() with NUTAG_NOTIFY_REFER() and NUTAG_REFER_EVENT()
- *
  * Settings:
  * - NUTAG_REFER_EXPIRES(), NUTAG_REFER_WITH_ID()
- *
  * Specifications:
  * - @RFC3515 (@ReferTo), @RFC3892 (@ReferredBy), @RFC3891 (@Replaces),
- *   @RFC4488 (@ReferSub)
+ *   @RFC4488, @ReferSub
  *
  * @par Internal SIP Event Server
- *
  * - nua_notifier(), #nua_r_notifier, #nua_i_subscription,
  *   nua_authorize(), #nua_r_authorize, nua_terminate(), #nua_r_terminate
  * - SIPTAG_EVENT(), SIPTAG_CONTENT_TYPE(), SIPTAG_PAYLOAD(),
  *   NUTAG_SUBSTATE()
- *
  * @par Settings
- *
  * - NUTAG_ALLOW_EVENTS(), SIPTAG_ALLOW_EVENTS(), and
  *                          SIPTAG_ALLOW_EVENTS_STR()
  * - NUTAG_MAX_SUBSCRIPTIONS()
  * - NUTAG_SUBSTATE(), NUTAG_SUB_EXPIRES()
- *
- * Specifications:
+ * @par Specifications
  * - @RFC3265
  *
  * @par SIP Event Subscriber
- *
  * - nua_subscribe(), #nua_r_subscribe, #nua_i_notify, NUTAG_SUBSTATE(),
  *   SIPTAG_EVENT(), SIPTAG_EXPIRES()
  * - nua_unsubscribe(), #nua_r_unsubscribe()
- *
- * Specifications:
+ * @par Specifications
  * - @RFC3265
  *
  * @par SIP Event Notifier
- *
  * - #nua_i_subscribe(), nua_notify(), #nua_r_notify,
  *   NUTAG_SUBSTATE(), NUTAG_SUB_EXPIRES(), SIPTAG_EVENT()
- *
  * Settings:
  * - NUTAG_SUB_EXPIRES()
  * - NUTAG_ALLOW_EVENTS(), SIPTAG_ALLOW_EVENTS(), and
  *                          SIPTAG_ALLOW_EVENTS_STR()
- * - @ref NUTAG_ALLOW("SUBSCRIBE"),
- *   @ref NUTAG_APPL_METHOD("SUBSCRIBE")
- *
- * Specifications
+ * - NUTAG_ALLOW("SUBSCRIBE"), NUTAG_APPL_METHOD("SUBSCRIBE")
+ * @par Specifications
  * - @RFC3265
  *
  * @par SIP Event Publisher
- *
  * - nua_publish(), #nua_r_publish(), nua_unpublish(), nua_r_unpublish()
  * - @SIPETag, SIPTAG_ETAG(), @SIPIfMatch, SIPTAG_IF_MATCH()
- *
- * Specifications:
+ * @par Specifications
  * - @RFC3903
  *
  * @par SIP Event State Compositor (PUBLISH Server)
- *
  * - #nua_i_publish, @SIPETag, @SIPIfMatch
- *
- * Settings:
- * - @ref NUTAG_ALLOW("PUBLISH"), @ref NUTAG_APPL_METHOD("PUBLISH")
- *
- * Specifications:
+ * @par Settings
+ * - NUTAG_ALLOW("PUBLISH"), NUTAG_APPL_METHOD("PUBLISH")
+ * @par Specifications
  * - @RFC3903
  *
  * @par Non-Standard Extension Methods
- *
  * - nua_method(), NUTAG_METHOD(), #nua_r_method, NUTAG_DIALOG()
  * - #nua_i_method, nua_respond()
- *
  * Settings:
  * - NUTAG_ALLOW(x), NUTAG_APPL_METHOD(x)
  *
  * @par Server Shutdown
- *
  * - nua_shutdown(), NUTAG_SHUTDOWN_EVENTS(), nua_destroy().
  */
 
@@ -692,6 +638,40 @@ tag_typedef_t nutag_retry_count = UINTTAG_TYPEDEF(retry_count);
  * Reference tag for NUTAG_RETRY_COUNT().
  */
 
+/**@def NUTAG_CALL_TLS_ORQ_CONNECT_TIMEOUT(x)
+ *
+ * Per Call Connect Timeout for outgoing requests using TLS.
+ *
+ * Overrides NTATAG_TLS_ORQ_CONNECT_TIMEOUT()
+ *
+ * @par Used with
+ *    nua_create(), nua_set_params(), nua_handle(), nua_set_hparams(),
+ *    nua_get_params(), nua_get_hparams(),
+ *    nua_register(), nua_unregister(),
+ *    nua_options(), nua_invite(), nua_ack(), nua_cancel(), nua_bye(),
+ *    nua_prack(), nua_update(), nua_info(),
+ *    nua_message(), nua_publish(), nua_unpublish(), nua_notifier(),
+ *    nua_subscribe(), nua_unsubscribe(), nua_notify(), nua_refer(),
+ *    nua_method(), nua_respond()
+ *    nua_authenticate().
+ *
+ * @par Parameter type
+ *    unsigned
+ *
+ * @par Values
+ * - 0 - Disabled
+ * - value - Milliseconds
+ *
+ * @NEW_1_13_2.
+ *
+ * Corresponding tag taking reference parameter is NUTAG_CALL_TLS_ORQ_CONNECT_TIMEOUT_REF().
+ */
+tag_typedef_t nutag_call_tls_orq_connect_timeout = UINTTAG_TYPEDEF(call_tls_orq_connect_timeout);
+
+/**@def NUTAG_CALL_TLS_ORQ_CONNECT_TIMEOUT_REF(x)
+ *
+ * Reference tag for NUTAG_CALL_TLS_ORQ_CONNECT_TIMEOUT().
+ */
 
 /**@def NUTAG_MAX_SUBSCRIPTIONS(x)
  *
@@ -1384,6 +1364,8 @@ tag_typedef_t nutag_autoanswer = BOOLTAG_TYPEDEF(autoAnswer);
  */
 tag_typedef_t nutag_autoack = BOOLTAG_TYPEDEF(autoACK);
 
+tag_typedef_t nutag_timer_autorequire = BOOLTAG_TYPEDEF(timerAutorequire);
+
 /**@def NUTAG_AUTOACK_REF(x)
  * Reference tag for NUTAG_AUTOACK().
  */
@@ -1467,78 +1449,6 @@ tag_typedef_t nutag_enablemessenger = BOOLTAG_TYPEDEF(enableMessenger);
  * Reference tag for NUTAG_ENABLEMESSENGER().
  */
 
-/**@def NUTAG_AUTO302(x)
- *
- * Recurse automatically on 302 response.
- *
- * If this parameter is true, a client recurses automatically upon receiving
- * a 302 response. The request is resent with the request-URI from the
- * @Contact header in the 302 response.
- *
- * @par Used with
- *    nua_create(), nua_set_params(), nua_set_hparams(), \n
- *    nua_get_params(), nua_get_hparams(), \n
- *    nua_invite(), nua_prack(), nua_ack(), nua_update(), nua_respond(), \n
- *    nua_info(), nua_cancel(), nua_bye(), \n
- *    nua_register(), nua_unregister(), nua_publish(), nua_unpublish(), \n
- *    nua_subscribe(), nua_unsubscribe(), nua_refer(), nua_notify(), \n
- *    nua_options(), nua_message(), nua_method()
- *
- * @par Parameter type
- *    int (boolean: nonzero is true, zero is false)
- *
- * @par Values
- *    - 0 (false) - process 302 as an ordinary final response
- *    - 1 (true) - resend request with URI received in 302 response
- *
- * Default value is NUTAG_AUTO302(1).
- *
- * Corresponding tag taking reference parameter is NUTAG_AUTO302_REF().
- */
-tag_typedef_t nutag_auto302 = BOOLTAG_TYPEDEF(auto302);
-
-/**@def NUTAG_AUTO302_REF(x)
- * Reference tag for NUTAG_AUTO302().
- */
-
-/**@def NUTAG_AUTO305(x)
- *
- * Recurse automatically on 305 response.
- *
- * If this parameter is true, a client recurses automatically upon receiving
- * a 305 response. The request is resent via the proxy specified by the
- * @Contact header in the 305 response. The proxy URI is included in the
- * @Route header of the request.
- *
- * Note that the NUTAG_PROXY() takes a precedence over the proxy in 305, and
- * the NUTAG_PROXY() is responsible of actually routing the request through
- * the 305 proxy.
- *
- * @par Used with
- *    nua_create(), nua_set_params(), nua_set_hparams(), \n
- *    nua_get_params(), nua_get_hparams(), \n
- *    nua_invite(), nua_prack(), nua_ack(), nua_update(), nua_respond(), \n
- *    nua_info(), nua_cancel(), nua_bye(), \n
- *    nua_register(), nua_unregister(), nua_publish(), nua_unpublish(), \n
- *    nua_subscribe(), nua_unsubscribe(), nua_refer(), nua_notify(), \n
- *    nua_options(), nua_message(), nua_method()
- *
- * @par Parameter type
- *    int (boolean: nonzero is true, zero is false)
- *
- * @par Values
- *    - 0 (false) - process 305 as an ordinary final response
- *    - 1 (true) - resend request via proxy received in 305 response
- *
- * Default value is NUTAG_AUTO305(1).
- *
- * Corresponding tag taking reference parameter is NUTAG_AUTO305_REF().
- */
-tag_typedef_t nutag_auto305 = BOOLTAG_TYPEDEF(auto305);
-
-/**@def NUTAG_AUTO305_REF(x)
- * Reference tag for NUTAG_AUTO305().
- */
 
 /**@def NUTAG_SMIME_ENABLE(x)
  *
@@ -1745,6 +1655,55 @@ tag_typedef_t nutag_sips_url = URLTAG_TYPEDEF(sips_url);
  * Reference tag for NUTAG_SIPS_URL().
  */
 
+/**@def NUTAG_WS_URL(x)
+ *
+ * Local WS url.
+ *
+ * The application can specify an alternative local address for
+ * NUA user agent engine. Usually the alternative address is a
+ *  SIP URI (WS) used with websocket transport.
+ *
+ * @par Used with
+ *    nua_create()
+ *
+ * @par Parameter type
+ *    char const *
+ *
+ * @par Values
+ *
+ * Corresponding tag taking reference parameter is NUTAG_WS_URL_REF().
+ */
+tag_typedef_t nutag_ws_url = URLTAG_TYPEDEF(ws_url);
+
+/**@def NUTAG_WS_URL_REF(x)
+ * Reference tag for NUTAG_WS_URL().
+ */
+
+
+/**@def NUTAG_WSS_URL(x)
+ *
+ * Local WSS url.
+ *
+ * The application can specify an alternative local address for
+ * NUA user agent engine. Usually the alternative address is a
+ * secure SIP URI (WSS) used with secure websocket transport.
+ *
+ * @par Used with
+ *    nua_create()
+ *
+ * @par Parameter type
+ *    char const *
+ *
+ * @par Values
+ *
+ * Corresponding tag taking reference parameter is NUTAG_WSS_URL_REF().
+ */
+tag_typedef_t nutag_wss_url = URLTAG_TYPEDEF(wss_url);
+
+/**@def NUTAG_WSS_URL_REF(x)
+ * Reference tag for NUTAG_WSS_URL().
+ */
+
 
 /**@def NUTAG_CERTIFICATE_DIR(x)
  *
@@ -2109,8 +2068,8 @@ tag_typedef_t nutag_instance = STRTAG_TYPEDEF(instance);
  * keepalive, use NUTAG_OUTBOUND("natify no-options-keepalive").
  *
  * An empty string can be passed to let the stack choose the
- * default values for outbound usage (in the 1.12.10 release, the
- * defaults are: "gruuize no-outbound validate use-rport options-keepalive").
+ * default values for outbound usage (in the 1.12.5 release, the
+ * defaults are: "gruuize no-outbound validate use-port options-keepalive").
  *
  * @note
  * Options string is used so that no new tags need to be added when the
@@ -2366,6 +2325,8 @@ tag_typedef_t nutag_auth = STRTAG_TYPEDEF(auth);
  *    - 0 (zero) - Use authentication data only for this handle
  *    - nonzero - Lifetime of authentication data in seconds
  *
+ * @todo
+ *
  * Corresponding tag taking reference parameter is NUTAG_AUTHTIME_REF().
  */
 tag_typedef_t nutag_authtime = INTTAG_TYPEDEF(authtime);
@@ -2583,6 +2544,31 @@ tag_typedef_t nutag_user_agent = STRTAG_TYPEDEF(user_agent);
  */
 
 
+/**@def NUTAG_VIA()
+ *
+ * Via string.
+ *
+ * Indicate the Via header used by the stack.
+ *
+ * @par Used with
+ *    nua_set_params(), nua_set_hparams() \n
+ *    nua_get_params(), nua_get_hparams(), #nua_r_get_params \n
+ *    any handle-specific nua call
+ *
+ * @par Parameter type
+ *    char const *
+ *
+ * @par Values
+ *    See @RFC3261 \n
+ *
+ * Corresponding tag taking reference parameter is NUTAG_VIA_REF().
+ */
+tag_typedef_t nutag_via = STRTAG_TYPEDEF(via);
+
+/**@def NUTAG_VIA_REF(x)
+ * Reference tag for NUTAG_VIA().
+ */
+
 /**@def NUTAG_ALLOW()
  *
  * Allow a method (or methods).
@@ -2761,6 +2747,29 @@ tag_typedef_t nutag_path_enable = BOOLTAG_TYPEDEF(path_enable);
  * Reference tag for NUTAG_PATH_ENABLE().
  */
 
+/**@def NUTAG_RETRY_AFTER_ENABLE(x)
+ *
+ * If true, support RFC 3261 Retry-After
+ *
+ * @par Used with
+ * - nua_create(), nua_set_params(), nua_get_params()
+ * - nua_handle(), nua_set_hparams(), nua_get_hparams()
+ * - nua_register()
+ *
+ * @par Parameter type
+ *    int (boolean: nonzero is true, zero is false)
+ *
+ * @par Values
+ *    - 0 (false) - Do not honor Retry-After
+ *    - 1 (true) - honor Retry-After
+ *
+ */
+tag_typedef_t nutag_retry_after_enable = BOOLTAG_TYPEDEF(retry_after_enable);
+
+/**@def NUTAG_RETRY_AFTER_ENABLE_REF(x)
+ * Reference tag for NUTAG_RETRY_AFTER_ENABLE().
+ */
+
 
 
 /**@def NUTAG_SERVICE_ROUTE_ENABLE(x)
@@ -2783,6 +2792,8 @@ tag_typedef_t nutag_path_enable = BOOLTAG_TYPEDEF(path_enable);
  * Corresponding tag taking reference parameter is NUTAG_SERVICE_ROUTE_ENABLE_REF().
  *
  * @sa NUTAG_INITIAL_ROUTE(), NUTAG_INITIAL_ROUTE_STR(), @RFC3608
+ *
+ * @todo
  */
 tag_typedef_t nutag_service_route_enable =
   BOOLTAG_TYPEDEF(service_route_enable);
@@ -2819,6 +2830,13 @@ tag_typedef_t nutag_auth_cache = INTTAG_TYPEDEF(auth_cache);
  * Reference tag for NUTAG_AUTH_CACHE().
  */
 
+/**@def NUTAG_AUTO_INVITE_100(x)
+ */
+tag_typedef_t nutag_auto_invite_100 = INTTAG_TYPEDEF(auto_invite_100);
+
+/**@def NUTAG_AUTO_INVITE_100(x)
+ * Reference tag for NUTAG_AUTO_INVITE_100().
+ */
 
 /**@def NUTAG_DETECT_NETWORK_UPDATES(x)
  *
@@ -2962,7 +2980,7 @@ tag_typedef_t nutag_dialog = UINTTAG_TYPEDEF(dialog);
 
 /**@def NUTAG_SIP_PARSER(x)
  *
- * Pointer to a customized SIP parser used with NUA.
+ * Pointer to SIP parser structure
  *
  * @par Used with
  *    nua_create()
