@@ -100,7 +100,7 @@
 #ifndef strncasecmp
 #define strncasecmp _strnicmp
 #endif
-#ifndef snprintf
+#if _MSC_VER < 1900
 #define snprintf    _snprintf
 #endif
 #ifndef vsnprintf
@@ -121,7 +121,7 @@
 #define SOFIA_USIZE_T size_t
 
 #ifdef _WIN64
-#define SOFIA_SSIZE_T __in64
+#define SOFIA_SSIZE_T __int64
 #define SOFIA_ISSIZE_T __int64
 #define SU_INTPTR_T __int64
 #elif _MSC_VER >= 1400
